      FUNCTION V3d(R,CT2,BL)
*  V3d is the MP4F3D potential energy surface for He-N2
*  as described in Reid et al, J. Chem. Phys. 107, 2329-2339 (1997)
*  V3d is returned in microhartrees
*  as a function of R and BL in bohr & CT2=cos(Theta)**2
*  BL is the bondlength of N2
*  CopyLeft: A.J. Thakkar, 1996
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION VRR(3)
      COMMON/RRPAR/ X(69)
      COMMON/POTPAR/A0,A2,A4,B0,B2,B4,G0,G2,G4,Rho,Rho2,Zeta,Zeta2,
     &  C60,C62,C80,C82,C84,C100,C102,C104,C106,rdiat,qrd2
* Calculate rotor potential at 3 fixed values of BL
      DO 10 jbl=1,3
        ishft=(jbl-1)*23
        A0   = X(1+ishft)
        A2   = X(2+ishft)
        A4   = X(3+ishft)
        B0   = X(4+ishft)
        B2   = X(5+ishft)
        B4   = X(6+ishft)
        G0   = X(7+ishft)
        G2   = X(8+ishft)
        G4   = X(9+ishft)
        Rho  = X(10+ishft)
        Rho2 = X(11+ishft)
        Zeta = X(12+ishft)
        Zeta2= X(13+ishft)
        C60  = X(14+ishft)
        C62  = X(15+ishft)
        C80  = X(16+ishft)
        C82  = X(17+ishft)
        C84  = X(18+ishft)
        C100 = X(19+ishft)
        C102 = X(20+ishft)
        C104 = X(21+ishft)
        C106 = X(22+ishft)
        rdiat= X(23+ishft)
        qrd2=0.25D0*rdiat**2
        VRR(jbl)=Vrot(R,CT2)
   10 CONTINUE
* Quadratic interpolation to obtain V3d at desired value of R
      V1=(VRR(3)-VRR(2))/(x(69)-x(46))
      V2=(VRR(1)-VRR(2)-V1*(x(23)-x(46)))/
     &((x(69)-x(23))*(x(23)-x(46)))
      V3d=(V2*(x(69)-BL)+V1)*(BL-x(46))+VRR(2)
      RETURN
      END
      FUNCTION Vrot(R,CT2)
* Rigid rotor He-N2 PES
* Vrot in microhartrees as a function of R in bohr & CT2=cos(Theta)**2
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER (rt6=2.44948974278317D0,
     &           rt8=2.82842712474619D0,
     &           rt10=3.16227766016837D0)
      COMMON/POTPAR/A0,A2,A4,B0,B2,B4,G0,G2,G4,Rho,Rho2,Zeta,Zeta2,
     &  C60,C62,C80,C82,C84,C100,C102,C104,C106,rdiat,qrd2
      RC=rdiat*R*SQRT(CT2)
      R2=R**2
      RA2=R2+qrd2-RC
      RB2=R2+qrd2+RC
      RA=SQRT(RA2)
      RB=SQRT(RB2)
      VRep=0.0D0
      Arg2=Zeta-Zeta2*RA
      IF(-Arg2.LT.90.0D0)VRep=VRep+EXP(Arg2)*SQRT(RA)
      Arg3=Zeta-Zeta2*RB
      IF(-Arg3.LT.90.0D0)VRep=VRep+EXP(Arg3)*SQRT(RB)
      P2=1.5D0*CT2-0.5D0
      P4=((35.0D0*CT2-30.0D0)*CT2+3.0D0)*0.125D0
*     P6=(((231.D0*CT2-315.D0)*CT2+105.D0)*CT2-5.D0)/16.D0
      A=A0+A2*P2+A4*P4
      B=B0+B2*P2+B4*P4
      G=G0+G2*P2+G4*P4
      VRep=VRep+EXP(A+G*LOG(R)-B*R)
      C6=C60+C62*P2
      C8=C80+C82*P2+C84*P4
      C10=C100+C102*P2+C104*P4
*     C10=C100+C102*P2+C104*P4+C106*P6
      RR=(Rho+Rho2*P2)*R
      RR2=RR**2
      D6 =(1.0D0-EXP(-2.1D0*RR/6.0D0 - 0.109D0*RR2/rt6))**6
      D8 =(1.0D0-EXP(-2.1D0*RR/8.0D0 - 0.109D0*RR2/rt8))**8
      D10=(1.0D0-EXP(-2.1D0*RR/10.0D0 - 0.109D0*RR2/rt10))**10
      R2=1.0D0/R**2
      VDis=((D10*C10*R2+D8*C8)*R2+D6*C6)*R2**3
      Vrot=(VRep-VDis)*1.0D+06
      RETURN
      END
      BLOCK DATA
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON/RRPAR/ X(69)
      DATA X/
     &  2.90038D+00,   7.16514D-01,   1.12334D+00,
     &  2.37623D+00,   2.11264D-01,  -2.74155D-01,
     &  1.98597D+00,   1.09078D+00,  -1.60141D+00,
     &  1.27265D+00,   3.54205D-01,   1.80300D-01,
     &  2.02043D+00,   9.41032D+00,   1.23081D+00,
     &  1.92408D+02,   1.61471D+02,  -6.16708D+00,
     &  1.15605D+04,   1.16074D+04,   4.43302D+03,
     &  0.00000D+00,   2.00000D+00,
     &  2.92808D+00,   7.51863D-01,   1.09543D+00,
     &  2.37630D+00,   2.18521D-01,  -2.78975D-01,
     &  1.99498D+00,   1.10519D+00,  -1.60122D+00,
     &  1.27435D+00,   3.86039D-01,   1.83154D-01,
     &  2.02705D+00,   9.74931D+00,   1.44401D+00,
     &  2.01405D+02,   1.74587D+02,  -1.72637D+01,
     &  1.16056D+04,   1.17802D+04,   5.41505D+03,
     &  0.00000D+00,   2.07430D+00,
     &  2.95358D+00,   9.11216D-01,   1.07881D+00,
     &  2.38034D+00,   2.20705D-01,  -2.79747D-01,
     &  1.99858D+00,   1.05817D+00,  -1.59990D+00,
     &  1.26607D+00,   4.07788D-01,   1.76151D-01,
     &  1.93547D+00,   1.02218D+01,   1.65207D+00,
     &  2.32280D+02,   1.95267D+02,   1.53978D+01,
     &  1.18847D+04,   1.32383D+04,   4.08916D+03,
     &  0.00000D+00,   2.20000D+00/
      END
